Enum Capability
#[non_exhaustive]#[repr(u32)]pub enum Capability {
ArbitraryModes = 1,
CursorPlane = 2,
}wayland and Linux only.Expand description
capabilities advertised by the compositor
Various capabilities that can be advertised by the compositor. They are advertised one-at-a-time when the wl_fullscreen_shell interface is bound. See the wl_fullscreen_shell.capability event for more details.
ARBITRARY_MODES: This is a hint to the client that indicates that the compositor is capable of setting practically any mode on its outputs. If this capability is provided, wl_fullscreen_shell.present_surface_for_mode will almost never fail and clients should feel free to set whatever mode they like. If the compositor does not advertise this, it may still support some modes that are not advertised through wl_global.mode but it is less likely.
CURSOR_PLANE: This is a hint to the client that indicates that the compositor can handle a cursor surface from the client without actually compositing. This may be because of a hardware cursor plane or some other mechanism. If the compositor does not advertise this capability then setting wl_pointer.cursor may degrade performance or be ignored entirely. If CURSOR_PLANE is not advertised, it is recommended that the client draw its own cursor and set wl_pointer.cursor(NULL).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ArbitraryModes = 1
compositor is capable of almost any output mode
CursorPlane = 2
compositor has a separate cursor plane